@@ -568,7 +568,7 @@ class CRM_Campaign_Page_AJAX {
    * This function uses the deprecated v1 datatable api and needs updating. See CRM-16353.
    * @deprecated
    */
-  public function campaignList() {
+  public static function campaignList() {
     //get the search criteria params.
     $searchCriteria = CRM_Utils_Request::retrieve('searchCriteria', 'String', CRM_Core_DAO::$_nullObject, FALSE, NULL, 'POST');
     $searchParams = explode(',', $searchCriteria);
