@@ -368,7 +368,7 @@ class CRM_Contact_BAO_Group extends CRM_Contact_DAO_Group {
       }
     }
     else {
-      $params['group_type'] = '';
+      $params['group_type'] = NULL;
     }
 
     $session = CRM_Core_Session::singleton();
@@ -752,7 +752,7 @@ class CRM_Contact_BAO_Group extends CRM_Contact_DAO_Group {
       $group['DT_RowId'] = 'row_' . $value['id'];
       if (!$params['parentsOnly']) {
         foreach ($value['class'] as $id => $class) {
-          if ($class = 'crm-group-parent') {
+          if ($class == 'crm-group-parent') {
             unset($value['class'][$id]);
           }
         }
