@@ -510,11 +510,13 @@ class CRM_Contact_Form_Contact extends CRM_Core_Form {
 
       for ($instance = 1; $instance <= $this->get($blockName . '_Block_Count'); $instance++) {
         // make we require one primary block, CRM-5505
-        if ($updateMode && !$hasPrimary) {
-          $hasPrimary = CRM_Utils_Array::value(
-            'is_primary',
-            CRM_Utils_Array::value($instance, $defaults[$name])
-          );
+        if ($updateMode) {
+          if (!$hasPrimary) {
+            $hasPrimary = CRM_Utils_Array::value(
+              'is_primary',
+              CRM_Utils_Array::value($instance, $defaults[$name])
+            );
+          }
           continue;
         }
 
