@@ -150,7 +150,7 @@ class CRM_Custom_Form_CustomData {
    *
    * @return array
    */
-  public static function setGroupTree(&$form, $subType, $gid, $onlySubType, $getCachedTree = FALSE) {
+  public static function setGroupTree(&$form, $subType, $gid, $onlySubType = NULL, $getCachedTree = FALSE) {
 
     $groupTree = CRM_Core_BAO_CustomGroup::getTree($form->_type,
       $form,
