@@ -44,6 +44,13 @@ class CRM_Extension_Info {
   public $label = NULL;
   public $file = NULL;
 
+  /**
+   * @var array
+   *   Each item is a specification like:
+   *   array('type'=>'psr4', 'namespace'=>'Foo\Bar', 'path'=>'/foo/bar').
+   */
+  public $classloader = array();
+
   /**
    * Load extension info an XML file.
    *
@@ -124,6 +131,16 @@ class CRM_Extension_Info {
         }
         ksort($this->urls);
       }
+      elseif ($attr === 'classloader') {
+        $this->classloader = array();
+        foreach ($val->psr4 as $psr4) {
+          $this->classloader[] = array(
+            'type' => 'psr4',
+            'prefix' => (string) $psr4->attributes()->prefix,
+            'path' => (string) $psr4->attributes()->path,
+          );
+        }
+      }
       else {
         $this->$attr = CRM_Utils_XML::xmlObjToArray($val);
       }
