@@ -415,6 +415,8 @@ class CRM_Extension_Mapper {
     if ($this->cache) {
       $this->cache->delete($this->cacheKey . '/moduleFiles');
     }
+    // FIXME: How can code so code wrong be so right?
+    CRM_Extension_System::singleton()->getClassLoader()->refresh();
   }
 
 }
