@@ -43,6 +43,11 @@ class CRM_Extension_System {
   private $browser = NULL;
   private $downloader = NULL;
 
+  /**
+   * @var CRM_Extension_ClassLoader
+   * */
+  private $classLoader;
+
   /**
    * The URL of the remote extensions repository.
    *
@@ -182,6 +187,16 @@ class CRM_Extension_System {
     return $this->mapper;
   }
 
+  /**
+   * @return \CRM_Extension_ClassLoader
+   */
+  public function getClassLoader() {
+    if ($this->classLoader === NULL) {
+      $this->classLoader = new CRM_Extension_ClassLoader($this->getMapper(), $this->getFullContainer(), $this->getManager());
+    }
+    return $this->classLoader;
+  }
+
   /**
    * Get the service for enabling and disabling extensions.
    *
