@@ -44,7 +44,13 @@ class CRM_Logging_Schema {
     'logging/contribute/summary',
   );
 
-  //CRM-13028 / NYSS-6933 - table => array (cols) - to be excluded from the update statement
+  /**
+   * Columns that should never be subject to logging.
+   *
+   * CRM-13028 / NYSS-6933 - table => array (cols) - to be excluded from the update statement
+   *
+   * @var array
+   */
   private $exceptions = array(
     'civicrm_job' => array('last_run'),
     'civicrm_group' => array('cache_date', 'refresh_date'),
@@ -121,6 +127,9 @@ AND    TABLE_NAME LIKE 'civicrm_%'
     //CRM-14672
     $this->tables = preg_grep('/^civicrm_menu/', $this->tables, PREG_GREP_INVERT);
     $this->tables = preg_grep('/_temp_/', $this->tables, PREG_GREP_INVERT);
+    // CRM-18178
+    $this->tables = preg_grep('/_bak$/', $this->tables, PREG_GREP_INVERT);
+    $this->tables = preg_grep('/_backup$/', $this->tables, PREG_GREP_INVERT);
 
     // do not log civicrm_mailing_event* tables, CRM-12300
     $this->tables = preg_grep('/^civicrm_mailing_event_/', $this->tables, PREG_GREP_INVERT);
@@ -656,9 +665,7 @@ COLS;
    * @param bool $force
    */
   public function triggerInfo(&$info, $tableName = NULL, $force = FALSE) {
-    // check if we have logging enabled
-    $config =& CRM_Core_Config::singleton();
-    if (!$config->logging) {
+    if (!CRM_Core_Config::singleton()->logging) {
       return;
     }
 
@@ -743,13 +750,11 @@ COLS;
    * Disable logging temporarily.
    *
    * This allow logging to be temporarily disabled for certain cases
-   * where we want to do a mass cleanup but dont want to bother with
-   * an audit trail
+   * where we want to do a mass cleanup but do not want to bother with
+   * an audit trail.
    */
   public static function disableLoggingForThisConnection() {
-    // do this only if logging is enabled
-    $config = CRM_Core_Config::singleton();
-    if ($config->logging) {
+    if (CRM_Core_Config::singleton()->logging) {
       CRM_Core_DAO::executeQuery('SET @civicrm_disable_logging = 1');
     }
   }
