@@ -72,6 +72,14 @@ class CRM_Mailing_Info extends CRM_Core_Component_Info {
       return array();
     }
 
+    $reportIds = array();
+    $reportTypes = array('detail', 'opened', 'bounce', 'clicks');
+    foreach ($reportTypes as $report) {
+      $result = civicrm_api3('ReportInstance', 'get', array(
+        'sequential' => 1,
+        'report_id' => 'mailing/' . $report));
+      $reportIds[$report] = $result['values'][0]['id'];
+    }
     $result = array();
     $result['crmMailing'] = array(
       'ext' => 'civicrm',
@@ -174,6 +182,7 @@ class CRM_Mailing_Info extends CRM_Core_Component_Info {
             )),
           'visibility' => CRM_Utils_Array::makeNonAssociative(CRM_Core_SelectValues::groupVisibility()),
           'workflowEnabled' => CRM_Mailing_Info::workflowEnabled(),
+          'reportIds' => $reportIds,
         ),
       ))
       ->addPermissions(array(
