@@ -310,21 +310,22 @@ WHERE cpse.id IS NOT NULL {$where}";
     $lineItem->label = $prevLabel;
     $lineItem->find();
     while ($lineItem->fetch()) {
-      $lineItem->label = $newLabel;
-      $lineItem->save();
+      $lineItemParams['id'] = $lineItem->id;
+      $lineItemParams['label'] = $newLabel;
+      CRM_Price_BAO_LineItem::create($lineItemParams);
+
       // update amount and fee level in civicrm_contribution and civicrm_participant
       $params = array(
         1 => array(CRM_Core_DAO::VALUE_SEPARATOR . $prevLabel . ' -', 'String'),
         2 => array(CRM_Core_DAO::VALUE_SEPARATOR . $newLabel . ' -', 'String'),
       );
+      // Update contribution
       if (!empty($lineItem->contribution_id)) {
         CRM_Core_DAO::executeQuery("UPDATE `civicrm_contribution` SET `amount_level` = REPLACE(amount_level, %1, %2) WHERE id = {$lineItem->contribution_id}", $params);
-        $participantIds = CRM_Event_BAO_Participant::getParticipantIds($lineItem->contribution_id);
-        foreach ($participantIds as $key => $id) {
-          if (!empty($id)) {
-            CRM_Core_DAO::executeQuery("UPDATE `civicrm_participant` SET `fee_level` = REPLACE(fee_level, %1, %2) WHERE id = {$id}", $params);
-          }
-        }
+      }
+      // Update participant
+      if ($lineItem->entity_table == 'civicrm_participant') {
+        CRM_Core_DAO::executeQuery("UPDATE `civicrm_participant` SET `fee_level` = REPLACE(fee_level, %1, %2) WHERE id = {$lineItem->entity_id}", $params);
       }
     }
   }
