@@ -67,6 +67,10 @@ class CRM_Report_Form_Contact_Relationship extends CRM_Report_Form {
             'name' => 'sort_name',
             'required' => TRUE,
           ),
+          'display_name_a' => array(
+            'title' => ts('Contact A Full Name'),
+            'name' => 'display_name',
+          ),
           'id' => array(
             'no_display' => TRUE,
             'required' => TRUE,
@@ -106,6 +110,10 @@ class CRM_Report_Form_Contact_Relationship extends CRM_Report_Form {
             'name' => 'sort_name',
             'required' => TRUE,
           ),
+          'display_name_b' => array(
+            'title' => ts('Contact B Full Name'),
+            'name' => 'display_name',
+          ),
           'id' => array(
             'no_display' => TRUE,
             'required' => TRUE,
@@ -261,11 +269,13 @@ class CRM_Report_Form_Contact_Relationship extends CRM_Report_Form {
         'filters' => array(
           'country_id' => array(
             'title' => ts('Country'),
+            'type' => CRM_Utils_Type::T_INT,
             'operatorType' => CRM_Report_Form::OP_MULTISELECT,
             'options' => CRM_Core_PseudoConstant::country(),
           ),
           'state_province_id' => array(
             'title' => ts('State/Province'),
+            'type' => CRM_Utils_Type::T_INT,
             'operatorType' => CRM_Report_Form::OP_MULTISELECT,
             'options' => CRM_Core_PseudoConstant::stateProvince(),
           ),
