@@ -154,6 +154,35 @@ class CRM_Upgrade_Incremental_php_FourSeven extends CRM_Upgrade_Incremental_Base
     $this->addTask('Add Index to civicrm_contribution creditnote_id field', 'addIndexContributionCreditNoteID');
   }
 
+  /**
+   * Upgrade function.
+   *
+   * @param string $rev
+   */
+  public function upgrade_4_7_2($rev) {
+    $this->addTask('Fix Index on civicrm_financial_item combined entity_id + entity_table', 'addCombinedIndexFinancialItemEntityIDEntityType');
+    $this->addTask('enable financial account relationships for chargeback & refund', 'addRefundAndChargeBackAccountsIfNotExist');
+    $this->addTask('Add Index to civicrm_contribution.source', 'addIndexContributionSource');
+  }
+
+  /**
+   * Upgrade function.
+   *
+   * @param string $rev
+   */
+  public function upgrade_4_7_3($rev) {
+    $this->addTask('Add Index to civicrm_contribution.total_amount', 'addIndexContributionAmount');
+  }
+
+  /**
+   * Upgrade function.
+   *
+   * @param string $rev
+   */
+  public function upgrade_4_7_4($rev) {
+    $this->addTask('Add Contact Deleted by Merge Activity Type', 'addDeletedByMergeActivityType');
+  }
+
   /**
    * CRM-16354
    *
@@ -258,7 +287,7 @@ class CRM_Upgrade_Incremental_php_FourSeven extends CRM_Upgrade_Incremental_Base
    * @return bool
    */
   public function addGettingStartedDashlet(CRM_Queue_TaskContext $ctx) {
-    $sql = "SELECT count(*) FROM civicrm_dashboard WHERE name='gettingStarted'";
+    $sql = "SELECT count(*) FROM civicrm_dashboard WHERE name='getting-started'";
     $res = CRM_Core_DAO::singleValueQuery($sql);
     $domainId = CRM_Core_Config::domainID();
     if ($res <= 0) {
@@ -427,4 +456,104 @@ FROM `civicrm_dashboard_contact` WHERE 1 GROUP BY contact_id";
     return TRUE;
   }
 
+  /**
+   * CRM-17775 Add correct index for table civicrm_financial_item.
+   *
+   * Note that the entity ID should always precede the entity_table as
+   * it is more unique. This is better for performance and does not cause fallback
+   * to no index if table it omitted.
+   *
+   * @return bool
+   */
+  public function addCombinedIndexFinancialItemEntityIDEntityType() {
+    CRM_Core_BAO_SchemaHandler::dropIndexIfExists('civicrm_financial_item', 'UI_id');
+    CRM_Core_BAO_SchemaHandler::dropIndexIfExists('civicrm_financial_item', 'IX_Entity');
+    CRM_Core_BAO_SchemaHandler::createIndexes(array(
+      'civicrm_financial_item' => array(array('entity_id', 'entity_table')),
+    ));
+    return TRUE;
+  }
+
+  /**
+   * CRM-17951 Add accounts option values for refund and chargeback.
+   *
+   * Add Chargeback contribution status and Chargeback and Contra account relationships,
+   * checking first if one exists.
+   */
+  public function addRefundAndChargeBackAccountsIfNotExist() {
+    // First we enable and edit the record for Credit contra - this exists but is disabled for most sites.
+    // Using the ensure function (below) will not enabled a disabled option (by design).
+    CRM_Core_DAO::executeQuery("UPDATE civicrm_option_value v
+     INNER JOIN civicrm_option_group g on v.option_group_id=g.id and g.name='account_relationship'
+     SET v.is_active=1, v.label='Credit/Contra Revenue Account is', v.name='Credit/Contra Revenue Account is', v.description='Credit/Contra Revenue Account is'
+     WHERE v.name = 'Credit/Contra Account is';");
+
+    CRM_Core_BAO_OptionValue::ensureOptionValueExists(array(
+      'option_group_id' => 'account_relationship',
+      'name' => 'Chargeback Account is',
+      'label' => ts('Chargeback Account is'),
+      'is_active' => TRUE,
+      'component_id' => 'CiviContribute',
+    ));
+
+    CRM_Core_BAO_OptionValue::ensureOptionValueExists(array(
+      'option_group_id' => 'contribution_status',
+      'name' => 'Chargeback',
+      'label' => ts('Chargeback'),
+      'is_active' => TRUE,
+      'component_id' => 'CiviContribute',
+    ));
+    return TRUE;
+  }
+
+  /**
+   * CRM-17999 Add index to civicrm_contribution.source.
+   *
+   * @param \CRM_Queue_TaskContext $ctx
+   *
+   * @return bool
+   */
+  public function addIndexContributionSource(CRM_Queue_TaskContext $ctx) {
+    CRM_Core_BAO_SchemaHandler::createIndexes(array('civicrm_contribution' => array('source')));
+    return TRUE;
+  }
+
+  /**
+   * CRM-18124 Add index to civicrm_contribution.total_amount.
+   *
+   * Note that I made this a combined index with receive_date because the issue included
+   * both criteria and they seemed likely to be used in conjunction to me in other cases.
+   *
+   * @param \CRM_Queue_TaskContext $ctx
+   *
+   * @return bool
+   */
+  public function addIndexContributionAmount(CRM_Queue_TaskContext $ctx) {
+    CRM_Core_BAO_SchemaHandler::createIndexes(array(
+      'civicrm_contribution' => array(array('total_amount', 'receive_date')),
+    ));
+    return TRUE;
+  }
+
+  /**
+   * CRM-18124 Add index to civicrm_contribution.total_amount.
+   *
+   * Note that I made this a combined index with receive_date because the issue included
+   * both criteria and they seemed likely to be used in conjunction to me in other cases.
+   *
+   * @param \CRM_Queue_TaskContext $ctx
+   *
+   * @return bool
+   */
+  public function addDeletedByMergeActivityType(CRM_Queue_TaskContext $ctx) {
+    CRM_Core_BAO_OptionValue::ensureOptionValueExists(array(
+      'option_group_id' => 'activity_type',
+      'name' => 'Contact Deleted by Merge',
+      'label' => ts('Contact Deleted by Merge'),
+      'description' => ts('Contact was merged into another contact'),
+      'is_active' => TRUE,
+    ));
+    return TRUE;
+  }
+
 }
